import os
import sys
from pathlib import Path
import json

import burningkeys.read_config as config


def create():
    path = Path(os.curdir) / config.file_name

    if path.exists():
        print(f"{config.file_name} file already exists at {Path(os.curdir).resolve()}")
        sys.exit(-1)

    path.touch(exist_ok=False)

    with open(path, "w") as file:
        json.dump({
            "Ctrl+P": "echo Hi, printing something or something",
            "Ctrl+Alt+M": [
                "echo This is the first command",
                "echo And this is the second"
            ]
        },file, indent="\t")



import shlex
from subprocess import run

import keyboard


def parse_command_sequence(key, value):
    if isinstance(value, str):
        command_sequence = [value]
    else:
        command_sequence = list(value)

    return key, command_sequence


def execute_command_sequence(command_sequence):
    for command in command_sequence:
        run(shlex.split(command))


def execute(config):
    for key, value in config:
        hotkey, command_sequence = parse_command_sequence(key, value)
        keyboard.add_hotkey(hotkey, execute_command_sequence, args=command_sequence)
    pass



import json
import os
import sys
from functools import cache
from pathlib import Path

file_name = "burningkeys.json"


def _read_config():
    path = Path(os.curdir) / file_name

    if not path.exists():
        print(f"No {file_name} file found at {Path(os.curdir).resolve()}", file=sys.stderr)
        sys.exit(-1)

    with open(path) as file:
        _config = json.load(file)
    return _config


@cache
def config():
    return _read_config()



import argparse

from burningkeys import example_config, read_config, execute_config


def command_entry_point():
    parser = argparse.ArgumentParser(prog="bkeys", description="Burningkeys is a lightweight python script to invoke "
                                                               "certain commands using hotkeys. This cli is meant mainly for coding."
                                                               "For example you might be editing in a basic text editor and would"
                                                               "like to invoke a linter on your project. Well now you can set that up")

    parser.add_argument("--create-example", action="store_true")

    args = parser.parse_args()

    if args.create_example:
        example_config.create()
        return

    config = read_config.config()
    execute_config.execute(config)
